@@ -41,9 +41,11 @@ class GSPDataSource(ImageDataSource):
     # zarr_path of where the gsp data is stored
     zarr_path: Union[str, Path]
     # start datetime, this can be None
-    start_dt: Optional[datetime] = None
+    # TODO: Issue #425: Use config to set start_dt and end_dt.
+    start_dt: Optional[datetime] = pd.Timestamp("2020-01-01")
     # end datetime, this can be None
-    end_dt: Optional[datetime] = None
+    # TODO: Issue #425: Use config to set start_dt and end_dt.
+    end_dt: Optional[datetime] = pd.Timestamp("2022-01-01")
     # the threshold where we only taken gsp's with a maximum power, above this value.
     threshold_mw: int = 0
     # get the data for the gsp at the center too.
@@ -53,12 +55,21 @@ class GSPDataSource(ImageDataSource):
     n_gsp_per_example: int = DEFAULT_N_GSP_PER_EXAMPLE
     # scale from zero to one
     do_scale_0_to_1: bool = False
+    # Drop any GSPs norther of this boundary.
+    # Many satellite images have a "rectangle of zeros" extending north from 1,037,047 meters
+    # (OSGB "northing" coordinate).  The largest satellite regions of interest are
+    # 144 km.  So set the boundary to be 1,037 km - (144 km / 2) = 1,036,975 meters.
+    # This results in 2 GSPs being dropped.
+    # See https://github.com/openclimatefix/Satip/issues/30
+    northern_boundary_osgb: Optional[float] = 1_036_975
 
     def __post_init__(self, image_size_pixels: int, meters_per_pixel: int):
         """
         Set random seed and load data
         """
         super().__post_init__(image_size_pixels, meters_per_pixel)
+        # TODO: Issue #425: Remove this logger warning.
+        logger.warning("GSPDataSource is using hard-coded start_dt and end_dt!")
         self.rng = np.random.default_rng()
         self.load()
 
@@ -83,7 +94,6 @@ class GSPDataSource(ImageDataSource):
         # load metadata
         self.metadata = get_gsp_metadata_from_eso()
         self.metadata.set_index("gsp_id", drop=False, inplace=True)
-        self.metadata.index.name = ""
 
         # make location x,y in osgb
         self.metadata["location_x"], self.metadata["location_y"] = lat_lon_to_osgb(
@@ -101,6 +111,11 @@ class GSPDataSource(ImageDataSource):
             self.gsp_power, self.metadata, threshold_mw=self.threshold_mw
         )
 
+        if self.northern_boundary_osgb is not None:
+            self.gsp_power, self.metadata = drop_gsp_north_of_boundary(
+                self.gsp_power, self.metadata, northern_boundary_osgb=self.northern_boundary_osgb
+            )
+
         logger.debug(f"There are {len(self.gsp_power.columns)} GSP")
 
     def datetime_index(self):
@@ -384,7 +399,9 @@ class GSPDataSource(ImageDataSource):
         return power, capacity
 
 
-def drop_gsp_by_threshold(gsp_power: pd.DataFrame, meta_data: pd.DataFrame, threshold_mw: int = 20):
+def drop_gsp_by_threshold(
+    gsp_power: pd.DataFrame, meta_data: pd.DataFrame, threshold_mw: int = 20
+) -> tuple[pd.DataFrame, pd.DataFrame]:
     """
     Drop GSP where the max power is below a certain threshold
 
@@ -399,14 +416,54 @@ def drop_gsp_by_threshold(gsp_power: pd.DataFrame, meta_data: pd.DataFrame, thre
 
     keep_index = maximum_gsp > threshold_mw
 
-    logger.debug(f"Dropping {sum(~keep_index)} GSPs as maximum is not greater {threshold_mw} MW")
+    dropped_gsp_names = meta_data.loc[keep_index[~keep_index].index].gsp_name
+
+    logger.debug(
+        f"Dropping {sum(~keep_index)} GSPs as maximum is not greater {threshold_mw} MW."
+        f" Dropped GSP IDs and GSP names:\n{dropped_gsp_names}"
+    )
     logger.debug(f"Keeping {sum(keep_index)} GSPs as maximum is greater {threshold_mw} MW")
 
-    gsp_power = gsp_power[keep_index.index]
-    gsp_ids = gsp_power.columns
-    meta_data = meta_data[meta_data["gsp_id"].isin(gsp_ids)]
+    filtered_gsp_power = gsp_power.loc[:, keep_index]
+    filtered_gsp_ids = filtered_gsp_power.columns
+    filtered_meta_data = meta_data[meta_data["gsp_id"].isin(filtered_gsp_ids)]
 
-    return gsp_power[keep_index.index], meta_data
+    assert set(filtered_gsp_power.columns) == set(filtered_meta_data.gsp_id)
+    return filtered_gsp_power, filtered_meta_data
+
+
+def drop_gsp_north_of_boundary(
+    gsp_power: pd.DataFrame, meta_data: pd.DataFrame, northern_boundary_osgb: int
+) -> tuple[pd.DataFrame, pd.DataFrame]:
+    """
+    Drop GSPs north of northern_boundary_osgb.
+
+    Args:
+        gsp_power: GSP power data
+        meta_data: the GSP meta data
+        northern_boundary_osgb: The geospatial boundary.
+
+    Returns: power data and metadata
+    """
+
+    keep_index = meta_data.location_y < northern_boundary_osgb
+    filtered_meta_data = meta_data.loc[keep_index]
+    filtered_gsp_ids = filtered_meta_data.gsp_id
+    filtered_gsp_power = gsp_power[filtered_gsp_ids]
+    pv_capacity_of_dropped_gsps = gsp_power.loc[:, ~keep_index].max()
+
+    logger.debug(
+        f"Dropping {sum(~keep_index)} GSPs because they are north of"
+        f" y={northern_boundary_osgb:,d}m:\n"
+        f" {meta_data.loc[~keep_index].gsp_name}\n with capacity in MW of:\n"
+        f"{pv_capacity_of_dropped_gsps}"
+    )
+    logger.debug(
+        f"Keeping {sum(keep_index)} GSPs because they are south of y={northern_boundary_osgb:,d}m."
+    )
+
+    assert set(filtered_gsp_power.columns) == set(filtered_meta_data.gsp_id)
+    return filtered_gsp_power, filtered_meta_data
 
 
 def load_solar_gsp_data(
